@@ -290,7 +290,7 @@ return(MF)
 #' @return fuzzy IF-THEN rule base
 #' @export 
 rulebase <- function(type.model, rule, func.tsk = NULL){
-if (class(rule) == "matrix"){
+if (inherits(rule, "matrix")){
 	rule.list <- list() 
 	for (i in 1 : nrow(rule)){
 		rule.list[i] <- list(rule[i, ])
@@ -1257,4 +1257,4 @@ ch.unique.fuzz <- function(type.model, rule, varinp.mf, varout.mf = NULL, num.va
 	return (list(rule = rule, varinp.mf = varinp.mf, varout.mf = varout.mf, 
 	           names.fvalinput = names.fvalinput, names.fvaloutput = names.fvaloutput, 
 			   names.fvalues = names.fvalues))
-}
\ No newline at end of file
+}
